<?php if (!defined('ABSPATH')) {
	die;
} // Cannot access directly.

/**
 * The Layout building class.
 */
class EFP_Display
{

	/**
	 * Display options section metabox.
	 *
	 * @param string $prefix The metabox key.
	 * @return void
	 */
	public static function section($prefix)
	{
		EFP::createSection(
			$prefix,
			array(
				'title'  => esc_html__('DISPLAY OPTIONS', 'eventful-pro'),
				'icon'   => 'fas fa-th-large',
				'fields' => array(
					array(
						'id'         => 'section_title',
						'type'       => 'switcher',
						'title'      => esc_html__('Section Title ', 'eventful-pro'),
						'subtitle'   => esc_html__('Show/Hide item showcase section title.', 'eventful-pro'),
						'default'    => false,
						'text_on'    => esc_html__('Show', 'eventful-pro'),
						'text_off'   => esc_html__('Hide', 'eventful-pro'),
						'text_width' => 75,
					),
					array(
						'id'              => 'section_title_margin',
						'type'            => 'spacing',
						'title'           => esc_html__('Section Title Margin', 'eventful-pro'),
						'subtitle'        => esc_html__('Set margin for the section title.', 'eventful-pro'),
						'all_icon'        => '<i class="fas fa-long-arrow-down"></i>',
						'units'           => array(
							'px',
						),
						'all_placeholder' => 'margin',
						'default'         => array(
							'top'    => '0',
							'right'  => '0',
							'bottom' => '30',
							'top'    => '0',
						),
						'dependency'      => array(
							'section_title',
							'==',
							'true',
							true,
						),
					),
					array(
						'id'       => 'efp_number_of_columns',
						'type'     => 'column',
						'title'    => esc_html__('Column(s)', 'eventful-pro'),
						'subtitle' => esc_html__('Set number of column(s) in different devices for responsive view.', 'eventful-pro'),
						'default'  => array(
							'lg_desktop'       => '3',
							'desktop'          => '3',
							'tablet'           => '2',
							'mobile_landscape' => '2',
							'mobile'           => '1',
						),
						'min'      => '1',
						'dependency' => array( 'efp_layout_preset', 'any', 'carousel_layout,grid_layout,filter_layout,large_with_small', true ),
						'help'       => wp_kses(esc_html__('<i class="fa fa-television"></i> <b> Large Desktop </b> - is larger than 1200px,<br><i class="fa fa-desktop"></i> <b>Desktop</b> - size is larger than 992px,<br> <i class="fa fa-tablet"></i> <b>Tablet</b> - Size is larger than 768,<br> <i class="fa fa-mobile"></i> <b> Mobile Landscape </b> - size is larger than 576px.,<br> <i class="fa fa-mobile"></i> <b> Mobile </b> - size is smaller than 576px.', 'eventful-pro'), array('i' => array('class' => array()), 'br' => array()) ),
					),
					array(
						'id'              => 'margin_between_post',
						'type'            => 'spacing',
						'title'           => esc_html__('Margin Between Columns', 'eventful-pro'),
						'subtitle'        => esc_html__('Set margin between columns (items).', 'eventful-pro'),
						'all'             => true,
						'all_icon'        => '<i class="fas fa-arrows-h"></i>',
						'units'           => array(
							'px',
						),
						'all_placeholder' => 'margin',
						'default'         => array(
							'all' => '20',
						),
					),
					array(
						'id'       => 'post_content_orientation',
						'type'     => 'layout_preset',
						'title'    => esc_html__('Content Orientation ', 'eventful-pro'),
						'subtitle' => esc_html__('Set a position for the item content.', 'eventful-pro'),
						'desc'     => esc_html__('More amazing Content Orientation and Layout', 'eventful-pro'),
						'class'    => 'efp-content-orientation',
						'options'  => array(
							'default'     => array(
								'image' => EFP_URL . 'admin/views/ta-framework/assets/img/default.png',
								'text'  => esc_html__('Default', 'eventful-pro'),
							),
							'overlay'     => array(
								'image'    => EFP_URL . 'admin/views/ta-framework/assets/img/overlay.png',
								'text'     => esc_html__('Overlay', 'eventful-pro'),
								'pro_only' => true,
							),
						),
						'default'  => 'default',
						'dependency' => array( 'efp_layout_preset', 'any', 'carousel_layout,grid_layout,filter_layout,large_with_small', true ),
					),
					array(
						'id'         => 'item_same_height',
						'type'       => 'checkbox',
						'title'      => esc_html__( 'Same Height', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Check to make all items/slides the same height as the tallest one.', 'eventful-pro' ),
						'default'    => false,
						'dependency' => array( 'efp_layout_preset', 'any', 'carousel_layout,grid_layout,filter_layout,large_with_small', true ),
					),
					array(
						'id'         => 'post_list_orientation',
						'type'       => 'layout_preset',
						'class'      => 'img_custom_width',
						'title'      => esc_html__( 'Content Orientation ', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Set a position for the post content.', 'eventful-pro' ),
						'options'    => array(
							'left-thumb'  => array(
								'image' => EFP_URL . 'admin/views/ta-framework/assets/img/left-image.svg',
								'text'  => esc_html__( 'Left Image', 'eventful-pro' ),
							),
							'right-thumb' => array(
								'image' => EFP_URL . 'admin/views/ta-framework/assets/img/right-image.svg',
								'text'  => esc_html__( 'Right Image', 'eventful-pro' ),
							),
						),
						'default'    => 'left-thumb',
						'dependency' => array( 'efp_layout_preset', '==', 'list_layout', true ),
					),
					array(
						'id'       => 'post_border',
						'type'     => 'border',
						'title'    => esc_html__('Border', 'eventful-pro'),
						'subtitle' => esc_html__('Set border for the item.', 'eventful-pro'),
						'all'      => true,
						'default'  => array(
							'all'   => '0',
							'style' => 'solid',
							'color' => '#e2e2e2',
						),
					),
					array(
						'id'       => 'post_border_radius_property',
						'type'     => 'spacing',
						'title'    => esc_html__('Border Radius', 'eventful-pro'),
						'subtitle' => esc_html__('Set border radius for item.', 'eventful-pro'),
						'all'      => true,
						'units'    => array('px', '%'),
						'default'  => array(
							'all' => '0',
						),
					),
					array(
						'id'       => 'show_post_box_shadow',
						'type'     => 'checkbox',
						'title'    => esc_html__( 'Box-Shadow', 'eventful-pro' ),
						'subtitle' => esc_html__( 'Show box-shadow for the item.', 'eventful-pro' ),
						'default'  => false,
					),
					array(
						'id'         => 'post_box_shadow_property',
						'type'       => 'box_shadow',
						'title'      => esc_html__( 'Box-Shadow Values', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Set box-shadow property values for the item.', 'eventful-pro' ),
						'default'    => array(
							'horizontal' => '0',
							'vertical'   => '0',
							'blur'       => '8',
							'spread'     => '-2',
							'color'      => 'rgb(187, 187, 187)',
						),
						'dependency' => array( 'show_post_box_shadow', '==', 'true' ),
					),
					array(
						'id'       => 'post_background_property',
						'type'     => 'color',
						'title'    => esc_html__('Background', 'eventful-pro'),
						'subtitle' => esc_html__('Set background color for the item.', 'eventful-pro'),
						'default'  => 'transparent',
						'dependency' => array( 'post_content_orientation', '!=', 'overlay' ),
					),
					array(
						'id'       => 'post_background_overlay',
						'type'     => 'color',
						'title'    => esc_html__('Background', 'eventful-pro'),
						'subtitle' => esc_html__('Set background color for the item. test', 'eventful-pro'),
						'default'  => '#14141F',
						'dependency' => array( 'post_content_orientation', '==', 'overlay' ),
					),
					array(
						'id'      => 'post_background_blur',
						'type'    => 'slider',
						'title'   => esc_html__('Slider', 'eventful-pro'),
						'min'     => 0,
						'max'     => 9,
						'step'    => 1,
						'unit'    => '',
						'default' => 7,
						'dependency' => array( 'post_content_orientation', '==', 'overlay' ),
					  ),
					  
					array(
						'id'       => 'post_inner_padding_property',
						'type'     => 'spacing',
						'title'    => esc_html__('Inner Padding', 'eventful-pro'),
						'subtitle' => esc_html__('Set inner padding for  item.', 'eventful-pro'),
						'default'  => array(
							'top'    => '0',
							'right'  => '0',
							'bottom' => '0',
							'left'   => '0',
							'unit'   => 'px',
						),
						'help'     => "<img src='" . EFP_URL . "/admin/assets/img/inner_padding.jpg'>",
					),
					array(
						'id'       => 'post_content_sorter',
						'type'     => 'sortable',
						'title'    => esc_html__('Content Fields', 'eventful-pro'),
						'subtitle' => esc_html__('Item content fields which are draggable to change display order and it\'s settings.', 'eventful-pro'),
						'class'    => 'post_content_sorter',
						'fields'   => array(
							array(
								'id'         => 'efp_post_thumb',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Thumbnail', 'eventful-pro'),
										'fields' => array(
											array(
												'id'       => 'post_thumb_show',
												'type'     => 'switcher',
												'title'    => esc_html__('Thumbnail', 'eventful-pro'),
												'text_on'  => esc_html__('Show', 'eventful-pro'),
												'text_off' => esc_html__('Hide', 'eventful-pro'),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'efp_thumb_sizes',
												'type'    => 'image_sizes',
												'title'   => esc_html__('Size', 'eventful-pro'),
												'default' => 'full',
												'dependency' => array('post_thumb_show', '==', 'true', true),
											),
											array(
												'id'       => 'efp_image_crop_size',
												'type'     => 'dimensions_advanced',
												'title'    => esc_html__('Custom Size', 'eventful-pro'),
												'chosen'   => true,
												'bottom'   => false,
												'left'     => false,
												'color'    => false,
												'top_icon' => '<i class="fas fa-arrows-h"></i>',
												'right_icon' => '<i class="fas fa-arrows-v"></i>',
												'top_placeholder' => 'width',
												'right_placeholder' => 'height',
												'styles'   => array(
													'Soft-crop',
													'Hard-crop',
												),
												'default'  => array(
													'top'  => '600',
													'right' => '400',
													'style' => esc_html__('Soft-crop', 'eventful-pro'),
													'unit' => 'px',
												),
												'attributes' => array(
													'min' => 0,
												),
												'dependency' => array('post_thumb_show|efp_thumb_sizes', '==|==', 'true|custom'),
											),
											array(
												'id'       => 'load_2x_image',
												'type'     => 'switcher',
												'title'    => esc_html__('Load 2x Resolution Image in Retina Display', 'eventful-pro'),
												'text_on'  => esc_html__('Enabled', 'eventful-pro'),
												'text_off' => esc_html__('Disabled', 'eventful-pro'),
												'text_width' => 94,
												'default'  => false,
												'dependency' => array('post_thumb_show|efp_thumb_sizes', '==|==', 'true|custom'),
											),
											array(
												'id'       => 'post_thumb_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
												'dependency' => array('post_thumb_show', '==', 'true'),
											),
											array(
												'id'      => 'efp_thumb_src_replace',
												'type'    => 'checkbox',
												'title'   => esc_html__('Replace With', 'eventful-pro'),
												'class'   => 'custom_help_text',
												'title_help' => esc_html__('This option will replace your default/featured post image with first resource ( image/video/audio ) from the content.', 'eventful-pro'),
												'options' => array(
													'image'   => esc_html__('Image', 'eventful-pro'),
													'video'   => esc_html__('Video', 'eventful-pro'),
													'audio'   => esc_html__('Audio', 'eventful-pro'),
												),
												'dependency' => array('post_thumb_show', '==', 'true'),
											),
											array(
												'id'      => 'post_featured_thumb_found',
												'type'    => 'select',
												'title'   => ' ',
												'options' => array(
													'no_featured_img_found' => esc_html__('If no featured image found', 'eventful-pro'),
													'even_featured_img_found' => esc_html__('Even featured image was found', 'eventful-pro'),
												),
												'default' => 'no_featured_img_found',
												'dependency' => array('post_thumb_show|efp_thumb_src_replace', '==|any', 'true|image,video,audio'),
											),

											array(
												'id'      => 'efp_thumb_border',
												'type'    => 'border',
												'title'   => esc_html__('Border', 'eventful-pro'),
												'all'     => true,
												'default' => array(
													'all' => '0',
													'style' => 'solid',
													'color' => '#dddddd',
												),
												'dependency' => array('post_thumb_show', '==', 'true'),
											),
											array(
												'id'       => 'post_thumb_border_radius',
												'type'     => 'spacing',
												'title'    => esc_html__('Border Radius', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'default'  => array(
													'top'    => '0',
													'right'  => '0',
													'bottom' => '0',
													'left'   => '0',
													'unit'   => 'px',
												  ),
												'dependency' => array('post_thumb_show', '==', 'true'),
											),

											array(
												'id'      => 'post_thumb_zoom',
												'type'    => 'select',
												'title'   => esc_html__('Zoom Effect', 'eventful-pro'),
												'options' => array(
													'none' => esc_html__('None', 'eventful-pro'),
													'zoom_in' => esc_html__('Zoom In', 'eventful-pro'),
													'zoom_out' => esc_html__('Zoom Out', 'eventful-pro'),
												),
												'default' => 'none',
												'dependency' => array('post_thumb_show', '==', 'true'),
											),
											array(
												'id'      => 'post_thumb_gray_scale',
												'type'    => 'select',
												'title'   => esc_html__('Image Mode', 'eventful-pro'),
												'options' => array(
													'none' => esc_html__('Normal', 'eventful-pro'),
													'gray_and_normal' => esc_html__('Grayscale and normal on hover', 'eventful-pro'),
													'gray_on_hover' => esc_html__('Grayscale on hover', 'eventful-pro'),
													'always_gray' => esc_html__('Always grayscale', 'eventful-pro'),
												),
												'default' => 'none',
												'dependency' => array('post_thumb_show', '==', 'true'),
											),
											array(
												'id'       => 'efp_img_lazy_load',
												'type'     => 'switcher',
												'class'    => 'custom_help_text',
												'title'    => esc_html__('Lazy Load', 'eventful-pro'),
												'title_help' => esc_html__('Defer image loading to improve performance.', 'eventful-pro'),
												'default'  => true,
												'text_on'  => esc_html__('Enabled', 'eventful-pro'),
												'text_off' => esc_html__('Disabled', 'eventful-pro'),
												'text_width' => 100,
												'dependency' => array('post_thumb_show|efp_layout_preset', '==|!=', 'true|carousel_layout', true),
											),
											array(
												'id'       => 'post_thumb_meta',
												'type'     => 'button_set',
												'title'   => esc_html__('Show Post Thumb Meta', 'eventful-pro'),
												'default'  => true,
												'options'    => array(
													'category'  => esc_html__('Category', 'eventful-pro'),
													'date' => esc_html__('Date', 'eventful-pro'),
													'none' => esc_html__('None', 'eventful-pro'),
												),
												'default'    => 'none',
												'dependency' => array('post_thumb_show', '==', 'true'),
											),
											array(
												'id'      => 'post_thumb_meta_taxonomy',
												'type'    => 'select',
												'title'   => esc_html__('Select Taxonomy', 'eventful-pro'),
												'options' => 'taxonomy',
												'query_args' => array(
													'type' => 'tribe_events',
												),
												'attributes' => array(
													'style' => 'width: 200px;',
												),
												'empty_message' => esc_html__('No taxonomies found.', 'eventful-pro'),
												'dependency' => array('post_thumb_show|post_thumb_meta', '==|==', 'true|category'),
											),
											array(
												'id'      => 'post_thumb_meta_date_format',
												'type'    => 'select',
												'title'   => esc_html__('Date Format', 'eventful-pro'),
												'options' => array(
													'default' => esc_html__('Default', 'eventful-pro'),
													'time_ago' => esc_html__('Time ago(human time)', 'eventful-pro'),
													'custom' => esc_html__('Custom', 'eventful-pro'),
												),
												'default' => 'default',
												'dependency' => array('select_post_meta', '==', 'date'),
											),
											array(
												'id'      => 'post_thumb_meta_position',
												'type'    => 'select',
												'title'   => esc_html__('Taxonomy Position', 'eventful-pro'),
												'subtitle'   => esc_html__( 'Select a position for the navigation arrows.', 'eventful-pro' ),
												'options'    => array(
													'top_right'                   => esc_html__( 'Top right', 'eventful-pro' ),
													'top_center'                  => esc_html__( 'Top center', 'eventful-pro' ),
													'top_left'                    => esc_html__( 'Top left', 'eventful-pro' ),
													'bottom_left'                 => esc_html__( 'Bottom left', 'eventful-pro' ),
													'bottom_center'               => esc_html__( 'Bottom center', 'eventful-pro' ),
													'bottom_right'                => esc_html__( 'Bottom right', 'eventful-pro' ),
												),
												'default'    => 'top_right',
												'dependency' => array('post_thumb_show|post_thumb_meta', '==|!=', 'true|none'),
											),
											array(
												'id'      => 'post_thumb_meta_button',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Read More Color', 'eventful-pro' ),
												'options' => array(
													'standard' => esc_html__( 'Text Color', 'eventful-pro' ),
													'hover' => esc_html__( 'Text Hover Color', 'eventful-pro' ),
													'bg' => esc_html__( 'Background', 'eventful-pro' ),
													'hover_bg' => esc_html__( 'Hover Background', 'eventful-pro' ),
													'border' => esc_html__( 'Border', 'eventful-pro' ),
													'hover_border' => esc_html__( 'Hover Border', 'eventful-pro' ),
												),
												'default' => array(
													'standard' => '#ffffff',
													'hover' => '#ffffff',
													'bg' => '#0015b5',
													'hover_bg' => '#263ad0',
													'border' => '#0015b5',
													'hover_border' => '#263ad0',
												),
												'dependency' => array('post_thumb_show|post_thumb_meta', '==|!=', 'true|none'),
											),
										),
									),
								),
							),
							array(
								'id'         => 'efp_post_title',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Title', 'eventful-pro'),
										'fields' => array(
											array(
												'id'       => 'show_post_title',
												'type'     => 'switcher',
												'title'    => esc_html__('Title', 'eventful-pro'),
												'text_on'  => esc_html__('Show', 'eventful-pro'),
												'text_off' => esc_html__('Hide', 'eventful-pro'),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'post_title_tag',
												'type'    => 'select',
												'title'   => esc_html__('Title HTML Tag', 'eventful-pro'),
												'options' => array(
													'h1'  => esc_html__('h1', 'eventful-pro'),
													'h2'  => esc_html__('h2', 'eventful-pro'),
													'h3'  => esc_html__('h3', 'eventful-pro'),
													'h4'  => esc_html__('h4', 'eventful-pro'),
													'h5'  => esc_html__('h5', 'eventful-pro'),
													'h6'  => esc_html__('h6', 'eventful-pro'),
													'p'   => esc_html__('p', 'eventful-pro'),
													'div' => esc_html__('div', 'eventful-pro'),
												),
												'default' => 'h2',
												'class'   => 'chosen',
												'dependency' => array('show_post_title', '==', 'true', true),
											),
											array(
												'id'      => 'post_title_limit',
												'type'    => 'checkbox',
												'title'   => esc_html__('Limit Character', 'eventful-pro'),
												'default' => false,
												'dependency' => array('show_post_title', '==', 'true'),
											),
											array(
												'id'       => 'efp_title_length',
												'type'     => 'spinner',
												'title'    => esc_html__('Length', 'eventful-pro'),
												'default'  => '30',
												'sanitize' => 'efp_sanitize_number_field',
												'unit'     => esc_html__('chars', 'eventful-pro'),
												'dependency' => array('post_title_limit|show_post_title', '==|==', 'true|true'),
											),
											array(
												'id'       => 'post_title_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array('px'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
												'dependency' => array('show_post_title', '==', 'true'),
											),
										),
									),
								),
							),

							array(
								'id'         => 'efp_post_meta',
								'class'      => 'efp_post_meta ta-product-not-fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Meta Fields', 'eventful-pro'),
										'fields' => array(
											array(
												'id'       => 'show_post_meta',
												'type'     => 'switcher',
												'title'    => esc_html__('Meta Fields', 'eventful-pro'),
												'text_on'  => esc_html__('Show', 'eventful-pro'),
												'text_off' => esc_html__('Hide', 'eventful-pro'),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'efp_post_meta_group',
												'class'   => 'efp_custom_group_design',
												'type'    => 'group',
												'button_title' => esc_html__('Add New Meta', 'eventful-pro'),
												'dependency' => array('show_post_meta', '==', 'true'),
												'fields'  => array(
													array(
														'id'       => 'select_post_meta',
														'class'       => 'select_post_meta',
														'type'     => 'select',
														'title'    => esc_html__('Select Meta', 'eventful-pro'),
														'placeholder' => esc_html__('Select a meta', 'eventful-pro'),
														'options'  => array(
															'author'  => esc_html__('Author', 'eventful-pro'),
															'date'   => esc_html__('Date', 'eventful-pro'),
															'taxonomy'   => esc_html__('Taxonomy', 'eventful-pro'),
															'comment_count'  => esc_html__('Comment Count', 'eventful-pro'),
															'view_count' => esc_html__('View Count', 'eventful-pro'),
															'like'     => esc_html__('Like', 'eventful-pro'),
															'reading_time'     => esc_html__('Reading Time', 'eventful-pro'),
														),
													),
													array(
														'id'      => 'post_meta_author_avatar',
														'type'    => 'select',
														'title'   => esc_html__('Avatar', 'eventful-pro'),
														'class'   => 'post_meta_author_avatar',
														'options' => array(
															'show_name' => esc_html__('Show name', 'eventful-pro'),
															'show_gravatar' => esc_html__('Show gravatar', 'eventful-pro'),
															'name_with_gravatar' => esc_html__('Author name & gravatar', 'eventful-pro'),
															'name_with_icon' => esc_html__('Author name with an icon', 'eventful-pro'),

														),
														'desc' => esc_html__('To show gravatar, you must <a href="https://wordpress.org/support/article/how-to-use-gravatars/" target="_blank" rel="noopener noreferrer nofollow"><em>enable it</em></a>.', 'eventful-pro'),
														'default' => 'name_with_icon',
														'dependency' => array('select_post_meta', '==', 'author'),
													),
													array(
														'id'      => 'post_meta_date_format',
														'type'    => 'select',
														'title'   => esc_html__('Date Format', 'eventful-pro'),
														'class'   => 'post_meta_date_format',
														'options' => array(
															'default' => esc_html__('Default', 'eventful-pro'),
															'time_ago' => esc_html__('Time ago(human time)', 'eventful-pro'),
															'custom' => esc_html__('Custom', 'eventful-pro'),
														),
														'default' => 'default',
														'dependency' => array('select_post_meta', '==', 'date'),
													),
													array(
														'id'    => 'efp_custom_meta_date_format',
														'type'  => 'text',
														'title' => ' ',
														'class' => 'efp_custom_meta_date_format',
														'placeholder' => esc_html__('F j, Y', 'eventful-pro'),
														'default'   => esc_html__('F j, Y', 'eventful-pro'),
														'desc' => __('To define format, check <a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank" rel="noopener noreferrer nofollow"><em>this doc</em></a>.', 'eventful-pro'),
														'dependency' => array('select_post_meta|post_meta_date_format', '==|==', 'date|custom'),
													),
													array(
														'id'      => 'post_meta_taxonomy',
														'type'    => 'select',
														'title'   => esc_html__('Select Taxonomy', 'eventful-pro'),
														'class'   => 'post_meta_taxonomy',
														'options' => 'taxonomy',
														'query_args' => array(
															'type' => 'post',
														),
														'attributes' => array(
															'style' => 'width: 200px;',
														),
														'empty_message' => esc_html__('No taxonomies found.', 'eventful-pro'),
														'dependency' => array('select_post_meta', '==', 'taxonomy'),
													),
													array(
														'id'      => 'efp_meta_position',
														'class'      => 'efp_meta_position',
														'type'    => 'button_set',
														'title'   => esc_html__('Position', 'eventful-pro'),
														'options' => array(
															'beside_meta' => esc_html__('Beside Other Meta', 'eventful-pro'),
															'above_title' => esc_html__('Above Title', 'eventful-pro'),
															'over_thumb' => esc_html__('Over Thumbnail', 'eventful-pro'),

														),
														'default' => 'beside_meta',
														'dependency' => array('select_post_meta', '==', 'taxonomy'),
													),
													array(
														'id'      => 'efp_meta_over_thump_position',
														'type'    => 'select',
														'title'   => esc_html__('Over Thumbnail Position', 'eventful-pro'),
														'options' => array(
															'top_left' => esc_html__('Top Left', 'eventful-pro'),
															'top_right' => esc_html__('Top Right', 'eventful-pro'),
															'bottom_left' => esc_html__('Bottom Left', 'eventful-pro'),
															'bottom_right' => esc_html__('Bottom Right', 'eventful-pro'),
														),
														'default' => 'top_left',
														'dependency' => array('select_post_meta|efp_meta_position', '==|==', 'taxonomy|over_thumb'),
													),
													array(
														'id'      => 'efp_meta_pill_color',
														'type'    => 'color_group',
														'title'   => esc_html__('Meta Color', 'eventful-pro'),
														'options' => array(
															'text' => esc_html__('Text', 'eventful-pro'),
															'bg' => esc_html__('Background', 'eventful-pro'),
														),
														'default' => array(
															'text' => '#fff',
															'bg' => '#e53935',
														),
														'dependency' => array('select_post_meta|efp_meta_position', '==|!=', 'taxonomy|beside_meta'),
													),
													array(
														'id'      => 'efp_word_per_minute',
														'type'    => 'number',
														'title'   => esc_html__('Per Minute', 'eventful-pro'),
														'class'   => 'efp_reading_time_meta',
														'title_help'   => esc_html__('Default 300 words, the average reading speed for adults.', 'eventful-pro'),
														'sanitize'        => 'efp_sanitize_number_field',
														'unit'   => esc_html__('words', 'eventful-pro'),
														'default' => '300',
														'dependency' => array('select_post_meta', '==', 'reading_time'),
														'default' => 300,
													),
													array(
														'id'      => 'select_meta_icon',
														'class'      => 'select_meta_icon',
														'type'    => 'icon',
														'title'   => esc_html__('Meta Icon', 'eventful-pro'),
														'default' => 'far fa-folder',
														'dependency' => array('efp_meta_position|select_post_meta', '==|!=', 'beside_meta|like'),
													),
													array(
														'id'      => 'reading_time_postfix',
														'type'    => 'text',
														'title'   => esc_html__('Reading Time Postfix', 'eventful-pro'),
														'class'   => 'efp_reading_time_postfix',
														'title_help'   => esc_html__('Text after time. Leave empty for nothing.', 'eventful-pro'),
														'default' => esc_html(' Min Read', 'eventful-pro'),
														'dependency' => array('select_post_meta', '==', 'reading_time'),
													),
												),
												'default' => array(
													array(
														'select_post_meta'    => 'author',
														'post_meta_author_avatar'    => 'name_with_icon',
														'select_meta_icon'    => 'fas fa-user',
														'efp_meta_position'     => 'beside_meta',
													),
													array(
														'select_post_meta'     => 'date',
														'select_meta_icon'    => 'fas fa-calendar',
														'efp_meta_position'     => 'beside_meta',
													),
													array(
														'select_post_meta'     => 'comment_count',
														'select_meta_icon'    => 'fas fa-calendar-alt',
														'efp_meta_position'     => 'beside_meta',
													),
												),
											),
											array(
												'id'      => 'meta_separator',
												'type'    => 'radio',
												'title'   => esc_html__('Meta Separator', 'eventful-pro'),
												'options' => array(
													' '  => esc_html__('Normal Space ', 'eventful-pro'),
													'. ' => esc_html__('Full Stop ( . ) ', 'eventful-pro'),
													'| ' => esc_html__('Straight Line ( | )', 'eventful-pro'),
													'/ ' => esc_html__('Slash ( / )', 'eventful-pro'),
													'\ ' => esc_html__('Back Slash( \\ )', 'eventful-pro'),
												),
												'default' => ' ',
												'dependency' => array('show_post_meta', '==', 'true'),
											),
											array(
												'id'      => 'meta_separator_color',
												'type'    => 'color',
												'title'   => esc_html__('Meta Separator Color', 'eventful-pro'),
												'default' => '#0015b5',
												'dependency' => array('show_post_meta', '==', 'true'),
											),
											array(
												'id'       => 'post_meta_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -100,
												'dependency' => array('show_post_meta', '==', 'true'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
											),
											array(
												'id'       => 'post_meta_between_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin Between Post Meta', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -5,
												'dependency' => array('show_post_meta', '==', 'true'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '0',
													'left' => '0',
												),
											),
										),
									),
								),
							),
							array(
								'id'         => 'efp_event_fildes',
								'class'      => 'efp_event_fildes ta-product-not-fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Event Fields', 'eventful-pro'),
										'fields' => array(
											array(
												'id'       => 'show_event_fildes',
												'type'     => 'switcher',
												'title'    => esc_html__('Meta Fields', 'eventful-pro'),
												'text_on'  => esc_html__('Show', 'eventful-pro'),
												'text_off' => esc_html__('Hide', 'eventful-pro'),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'efp_event_fildes_group',
												'class'   => 'efp_custom_group_design',
												'type'    => 'group',
												'button_title' => esc_html__('Add New Meta', 'eventful-pro'),
												'dependency' => array('show_event_fildes', '==', 'true'),
												'fields'  => array(
													array(
														'id'       => 'select_event_fildes',
														'class'       => 'select_event_fildes',
														'type'     => 'select',
														'title'    => esc_html__('Select Meta', 'eventful-pro'),
														'placeholder' => esc_html__('Select a meta', 'eventful-pro'),
														'options'  => array(
															'venue'     => esc_html__('Venue', 'eventful-pro'),
															'organizer'     => esc_html__('Organizer', 'eventful-pro'),
															'price'     => esc_html__('Price', 'eventful-pro'),
															'event_time'     => esc_html__('Event Time', 'eventful-pro'),
														),
													),
													array(
														'id'      => 'venue_map_link',
														'type'    => 'switcher',
														'title'   => esc_html__('Show Map Link', 'eventful-pro'),
														'class'   => 'venue_map_link',
														'title_help'   => esc_html__('Set show map link.', 'eventful-pro'),
														'default' => true,
														'dependency' => array('select_event_fildes', '==', 'venue'),
													),
													array(
														'id'      => 'select_event_fildes_icon',
														'class'      => 'select_event_fildes_icon',
														'type'    => 'icon',
														'title'   => esc_html__('Meta Icon', 'eventful-pro'),
														'default' => 'far fa-folder',
													),
													array(
														'id'      => 'event_fildes_date_type',
														'type'    => 'radio',
														'title'   => esc_html__('Date Type', 'eventful-pro'),
														'class'   => 'event_fildes_date_type',
														'options' => array(
															'start_date' => esc_html__('Start Date and Time', 'eventful-pro'),
															'end_date' => esc_html__('End Date and Time', 'eventful-pro'),
															'start_date_time_with_end_date_time' => esc_html__('Start Date Time With End Date Time', 'eventful-pro'),
														),
														'default' => 'start_date',
														'dependency' => array('select_event_fildes', '==', 'event_time'),
													),
													array(
														'id'    => 'event_fildes_date_format',
														'type'    => 'select',
														'title' => ' ',
														'class' => 'event_fildes_date_format',
														'options' => array(
															'j F, Y g:i A' => esc_html__('Default (01 January 2024 12:00 AM)', 'eventful-pro'),
															'F j, Y g:i A' => esc_html__('Default (January 01 2024 12:00 AM)', 'eventful-pro'),
															'F j, g:i A' => esc_html__('Default (January 01 12:00 AM)', 'eventful-pro'),
															'j F, g:i A' => esc_html__('Default ( 01 January 12:00 AM)', 'eventful-pro'),
															'j M, g:i A' => esc_html__('Default ( 01 Jan 12:00 AM)', 'eventful-pro'),
															'M j, g:i A' => esc_html__('Default ( Jan 01 12:00 AM)', 'eventful-pro'),
															'j F, Y' => esc_html__('Default (01 January 2024)', 'eventful-pro'),
															'F j, Y' => esc_html__('Default (January 01 2024)', 'eventful-pro'),
															'j F, Y' => esc_html__('Default (01 January 2024)', 'eventful-pro'),
															'M j, Y' => esc_html__('Default (Jan 01 2024)', 'eventful-pro'),
															'j M, Y' => esc_html__('Default (01 Jan 2024)', 'eventful-pro'),
															'g:i A' => esc_html__('Default (12:50 AM)', 'eventful-pro'),
															'G:i' => esc_html__('Default (23:00)', 'eventful-pro'),
															'custom' => esc_html__('Custom', 'eventful-pro'),
														),
														'default'   => esc_html__('j F, Y g:i A', 'eventful-pro'),
														'desc' => __('To define format, check <a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank" rel="noopener noreferrer nofollow"><em>this doc</em></a>.', 'eventful-pro'),
														'dependency' => array('select_event_fildes', '==', 'event_time'),
													),
													array(
														'id'    => 'efp_custom_event_date_format',
														'type'  => 'text',
														'title' => ' ',
														'class' => 'efp_custom_event_date_format',
														'placeholder' => esc_html__('j F, Y g:i A', 'eventful-pro'),
														'default'   => esc_html__('j F, Y g:i A', 'eventful-pro'),
														'desc' => __('To define format, check <a href="https://wordpress.org/support/article/formatting-date-and-time/" target="_blank" rel="noopener noreferrer nofollow"><em>this doc</em></a>.', 'eventful-pro'),
														'dependency' => array('select_event_fildes|event_fildes_date_format', '==|==', 'event_time|custom'),
													),
												),

												
												'default' => array(
													array(
														'select_event_fildes'    => 'venue',
														'select_event_fildes_icon'    => 'fas fa-map-marker-alt',
													),
													array(
														'select_event_fildes'     => 'event_time',
														'select_event_fildes_icon'    => 'far fa-clock',
													),
													array(
														'select_event_fildes'     => 'price',
														'select_event_fildes_icon'    => 'fas fa-money-check-alt',
													),
												),
											),
											array(
												'id'      => 'event_meta_separator',
												'type'    => 'radio',
												'title'   => esc_html__('Event Meta Separator', 'eventful-pro'),
												'options' => array(
													' '  => esc_html__('Normal Space ', 'eventful-pro'),
													'. ' => esc_html__('Full Stop ( . ) ', 'eventful-pro'),
													'| ' => esc_html__('Straight Line ( | )', 'eventful-pro'),
													'/ ' => esc_html__('Slash ( / )', 'eventful-pro'),
													'\ ' => esc_html__('Back Slash( \\ )', 'eventful-pro'),
												),
												'default' => ' ',
												'dependency' => array('show_event_fildes', '==', 'true'),
											),
											array(
												'id'      => 'event_meta_separator_color',
												'type'    => 'color',
												'title'   => esc_html__('Event Meta Separator Color', 'eventful-pro'),
												'default' => '#0015b5',
												'dependency' => array('show_event_fildes', '==', 'true'),
											),
											array(
												'id'       => 'event_fildes_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -100,
												'dependency' => array('show_event_fildes', '==', 'true'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
											),
											array(
												'id'       => 'event_fildes_between_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin Between Post Meta', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array('px'),
												'min'      => -5,
												'dependency' => array('show_event_fildes', '==', 'true'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '0',
													'left' => '0',
												),
											),
										),
									),
								),
							),
							array(
								'id'         => 'efp_post_content',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__('Content', 'eventful-pro'),
										'fields' => array(
											array(
												'id'       => 'show_post_content',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Content', 'eventful-pro' ),
												'text_on'  => esc_html__( 'Show', 'eventful-pro' ),
												'text_off' => esc_html__( 'Hide', 'eventful-pro' ),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'post_content_type',
												'type'    => 'select',
												'title'   => esc_html__( 'Content Display Type', 'eventful-pro' ),
												'options' => array(
													'excerpt'      => esc_html__( 'Excerpt', 'eventful-pro' ),
													'limit_content' => esc_html__( 'Content with Limit', 'eventful-pro' ),
													'full_content' => esc_html__( 'Full Content', 'eventful-pro' ),
												),
												'default' => 'limit_content',
												'dependency' => array( 'show_post_content', '==', 'true' ),
											),
											array(
												'id'      => 'efp_content_length_type',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Content Length Type', 'eventful-pro' ),
												'options' => array(
													'words'    => esc_html__( 'Words', 'eventful-pro' ),
													'characters' => esc_html__( 'Characters', 'eventful-pro' ),
												),
												'default' => 'words',
												'dependency' => array( 'show_post_content|post_content_type', '==|==', 'true|limit_content' ),
											),
											array(
												'id'       => 'efp_content_limit',
												'type'     => 'spinner',
												'title'    => esc_html__( 'Words Length', 'eventful-pro' ),
												'sanitize' => 'efp_sanitize_number_field',
												'default'  => 30,
												'max'      => 10000,
												'dependency' => array( 'show_post_content|post_content_type|efp_content_length_type', '==|==|==', 'true|limit_content|words' ),
											),
											array(
												'id'       => 'efp_content_characters_limit',
												'type'     => 'spinner',
												'title'    => esc_html__( 'Characters Length', 'eventful-pro' ),
												'sanitize' => 'efp_sanitize_number_field',
												'default'  => 300,
												'max'      => 10000,
												'dependency' => array( 'show_post_content|post_content_type|efp_content_length_type', '==|==|==', 'true|limit_content|characters' ),
											),
											array(
												'id'       => 'post_content_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'eventful-pro' ),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
												'dependency' => array( 'show_post_content', '==', 'true' ),
											),
											array(
												'id'      => 'efp_strip_tags',
												'type'    => 'radio',
												'title'   => esc_html__( 'HTML Tags', 'eventful-pro' ),
												'options' => array(
													'allow_all'  => esc_html__( 'Allow All', 'eventful-pro' ),
													'strip_all'  => esc_html__( 'Strip All', 'eventful-pro' ),
													'allow_some' => esc_html__( 'Allow Some', 'eventful-pro' ),
												),
												'default' => 'allow_all',
												'dependency' => array( 'show_post_content|post_content_type', '==|!=', 'true|excerpt' ),
											),
											array(
												'id'    => 'efp_allow_tag_name',
												'type'  => 'text',
												'title' => esc_html__( 'Allow HTML Tags Names', 'eventful-pro' ),
												'title_help' => esc_html__( 'Separate multiple tags by comma, e.g. h1,h2', 'eventful-pro' ),
												'dependency' => array( 'show_post_content|efp_strip_tags', '==|==', 'true|allow_some' ),
											),
											array(
												'id'      => 'post_content_ellipsis',
												'type'    => 'text',
												'title'   => esc_html__( 'Ellipsis Points Ending Excerpt', 'eventful-pro' ),
												'default' => '...',
												'dependency' => array( 'show_post_content|post_content_type', '==|!=', 'true|full_content' ),
											),
										),
									),
								),
							),
							array(
								'id'         => 'efp_post_content_readmore',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html('Read more', 'eventful-pro'),
										'fields' => array(
											// ReadMore settings.
											array(
												'id'       => 'show_read_more',
												'type'     => 'switcher',
												'title'    => esc_html__( 'Read More', 'eventful-pro' ),
												'text_on'  => esc_html__( 'Show', 'eventful-pro' ),
												'text_off' => esc_html__( 'Hide', 'eventful-pro' ),
												'default'  => true,
												'text_width' => 80,
											),
											array(
												'id'      => 'read_more_type',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Read More Type', 'eventful-pro' ),
												'options' => array(
													'button'    => esc_html__( 'Button', 'eventful-pro' ),
													'text_link' => esc_html__( 'Text Link', 'eventful-pro' ),
												),
												'default' => 'button',
												'dependency' => array( 'show_read_more', '==', 'true' ),
											),
											array(
												'id'      => 'efp_read_label',
												'type'    => 'text',
												'title'   => esc_html__( 'Read More Label', 'eventful-pro' ),
												'default' => 'Read More',
												'dependency' => array( 'show_read_more', '==', 'true' ),
											),
											array(
												'id'      => 'readmore_color_button',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Read More Color', 'eventful-pro' ),
												'options' => array(
													'standard' => esc_html__( 'Text Color', 'eventful-pro' ),
													'hover' => esc_html__( 'Text Hover Color', 'eventful-pro' ),
													'bg' => esc_html__( 'Background', 'eventful-pro' ),
													'hover_bg' => esc_html__( 'Hover Background', 'eventful-pro' ),
													'border' => esc_html__( 'Border', 'eventful-pro' ),
													'hover_border' => esc_html__( 'Hover Border', 'eventful-pro' ),
												),
												'default' => array(
													'standard' => '#ffffff',
													'hover' => '#ffffff',
													'bg' => '#0015b5',
													'hover_bg' => '#263ad0',
													'border' => '#0015b5',
													'hover_border' => '#263ad0',
												),
												'dependency' => array( 'show_read_more|read_more_type', '==|==', 'true|button' ),
											),
											array(
												'id'       => 'readmore_padding',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Padding', 'eventful-pro' ),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'default'  => array(
													'top'  => '6',
													'right' => '20',
													'bottom' => '6',
													'left' => '20',
												),
												'dependency' => array( 'show_read_more|read_more_type', '==|==', 'true|button' ),
											),
											array(
												'id'       => 'readmore_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'eventful-pro' ),
												'sanitize' => 'efp_sanitize_number_array_field',
												'units'    => array( 'px' ),
												'min'      => -100,
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '20',
													'left' => '0',
												),
												'dependency' => array( 'show_read_more', '==', 'true' ),
											),
											array(
												'id'       => 'readmore_button_radius',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Border Radius', 'eventful-pro' ),
												'sanitize' => 'efp_sanitize_number_array_field',
												'all'      => true,
												'default'  => array(
													'all'  => '0',
													'unit' => 'px',
												),
												'units'    => array( 'px', '%' ),
												'dependency' => array( 'show_read_more|read_more_type', '==|==', 'true|button' ),
											),
											array(
												'id'      => 'readmore_color_text',
												'type'    => 'color_group',
												'title'   => esc_html__( 'Read More Color', 'eventful-pro' ),
												'options' => array(
													'standard' => esc_html__( 'Text Color', 'eventful-pro' ),
													'hover' => esc_html__( 'Text Hover Color', 'eventful-pro' ),
												),
												'default' => array(
													'standard' => '#ffffff',
													'hover' => '#0015b5',
												),
												'dependency' => array( 'show_read_more|read_more_type', '==|==', 'true|text_link' ),
											),

										),
									),
								),
							),
							array(
								'id'         => 'efp_social_share',
								'type'       => 'accordion',
								'class'      => 'efp-pro-only',
								'accordions' => array(
									array(
										'title'  => esc_html__('Social Share', 'eventful-pro'),
										'fields' => array(
											array(
												'id'       => 'social_sharing_media',
												'type'     => 'select',
												'title'    => esc_html__('Sharing Media', 'eventful-pro'),
												'chosen'   => true,
												'sortable' => true,
												'multiple' => true,
												'placeholder' => esc_html__('Choose an option', 'eventful-pro'),
												'options'  => array(
													'facebook' => esc_html__('Facebook', 'eventful-pro'),
													'twitter' => esc_html__('Twitter', 'eventful-pro'),
													'linkedIn' => esc_html__('LinkedIn', 'eventful-pro'),
													'pinterest' => esc_html__('Pinterest', 'eventful-pro'),
													'email' => esc_html__('Email', 'eventful-pro'),
													'instagram' => esc_html__('Instagram', 'eventful-pro'),
													'vk'   => esc_html__('VK', 'eventful-pro'),
													'digg' => esc_html__('digg', 'eventful-pro'),
													'tumblr' => esc_html__('Tumblr', 'eventful-pro'),
													'reddit' => esc_html__('Reddit', 'eventful-pro'),
													'whatsapp' => esc_html__('WhatsApp', 'eventful-pro'),
													'pocket' => esc_html__('Pocket', 'eventful-pro'),
													'xing' => esc_html__('Xing', 'eventful-pro'),
												),
											),
											array(
												'id'      => 'social_position',
												'type'    => 'button_set',
												'title'   => esc_html__('Alignment', 'eventful-pro'),
												'options'    => array(
													'left'   => wp_kses( __('<i class="fas fa-align-left" title="Left"></i>', 'eventful-pro'), array('i' => array('class' => array()))),
													'center' => wp_kses( __('<i class="fas fa-align-center" title="Center"></i>', 'eventful-pro'), array('i' => array('class' => array()))),
													'right'  => wp_kses( __('<i class="fas fa-align-right" title="Right"></i>', 'eventful-pro'), array('i' => array('class' => array()))),
												),
												'default' => 'left',
												'dependency' => array('social_sharing_media', '!=', ''),
											),
											array(
												'id'       => 'social_margin',
												'type'     => 'spacing',
												'title'    => esc_html__('Margin', 'eventful-pro'),
												'sanitize' => 'efp_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array('px'),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '0',
													'left' => '0',
												),
												'dependency' => array('social_sharing_media', '!=', ''),
											),
											array(
												'id'      => 'social_icon_shape',
												'class'   => 'social_icon_shape',
												'type'    => 'layout_preset',
												'title'   => esc_html__('Icon Shape', 'eventful-pro'),
												'options' => array(
													'efp_circle'    => array(
														'image'       => EFP_URL . 'admin/assets/img/circle-icon.png',
														'text' => esc_html__('Circle', 'eventful-pro'),
													),
													'efp_rounded'   => array(
														'image'       => EFP_URL . 'admin/assets/img/round-icon.png',
														'text' => esc_html__('Rounded', 'eventful-pro'),
													),
													'efp_square'    => array(
														'image'       => EFP_URL . 'admin/assets/img/square-icon.png',
														'text' => esc_html__('Square', 'eventful-pro'),
													),
													'icon_only' => array(
														'image'       => EFP_URL . 'admin/assets/img/only-icon.png',
														'text' => esc_html__('Icon only', 'eventful-pro'),
													),
												),
												'default' => 'efp_circle',
												'dependency' => array('social_sharing_media', '!=', ''),
											),
											array(
												'id'      => 'social_icon_custom_color',
												'type'    => 'checkbox',
												'title'   => esc_html__('Custom Color', 'eventful-pro'),
												'default' => false,
												'dependency' => array('social_sharing_media', '!=', ''),
											),
											array(
												'id'      => 'social_icon_color',
												'type'    => 'color_group',
												'title'   => esc_html__('Icon Color', 'eventful-pro'),
												'options' => array(
													'icon_color'       => esc_html__('Icon', 'eventful-pro'),
													'icon_hover_color' => esc_html__('Icon Hover', 'eventful-pro'),
													'icon_bg'       => esc_html__('Background', 'eventful-pro'),
													'icon_bg_hover' => esc_html__('Background Hover', 'eventful-pro'),
													'icon_border_hover' => esc_html__('Border Hover', 'eventful-pro'),
												),
												'default' => array(
													'icon_color'       => '#ffffff',
													'icon_hover_color' => '#ffffff',
													'icon_bg'       => '#0015b5',
													'icon_bg_hover' => '#263ad0',
													'icon_border_hover' => '#263ad0',
												),
												'dependency' => array('social_icon_custom_color|social_sharing_media', '==|!=', 'true|'),
											),
											array(
												'id'      => 'social_icon_border',
												'type'    => 'border',
												'title'   => esc_html__('Icon Border', 'eventful-pro'),
												'default' => array(
													'all' => '1',
													'style' => 'solid',
													'color' => '#0015b5',
												),
												'all'     => true,
												'dependency' => array('social_icon_custom_color|social_sharing_media', '==|!=', 'true|'),
											),
										),
									),
								),
							), // PCP Post Social.
							array(
								'id'         => 'efp_custom_fields',
								'type'       => 'accordion',
								'accordions' => array(
									array(
										'title'  => esc_html__( 'Custom Fields', 'eventful-pro' ),
										'fields' => array(
											// The Group Fields.
											array(
												'id'     => 'efp_custom_fields_group',
												'class'  => 'efp_custom_group_design',
												'type'   => 'group',
												'accordion_title_auto' => true,
												'accordion_title_number' => true,
												'button_title' => esc_html__( 'Add New Custom Field', 'eventful-pro' ),
												'fields' => array(
													array(
														'id'   => 'efp_select_custom_field_key',
														'type' => 'select',
														'title' => esc_html__( 'Custom Fields', 'eventful-pro' ),
														'options' => 'custom_fields',
														'chosen' => true,
														'attributes' => array(
															'style' => 'width: 200px;',
														),
														'empty_message' => esc_html__( 'No custom field found.', 'eventful-pro' ),
													),
													array(
														'id'   => 'efp_custom_meta_icon',
														'type' => 'icon',
														'title' => esc_html__('Icon Before Name', 'eventful-pro'),
														'default' => 'fas fa-calendar-alt',
													),
													array(
														'id'   => 'show_custom_field_name',
														'type' => 'switcher',
														'title'    => esc_html__( 'Custom Field Name', 'eventful-pro' ),
														'text_on' => esc_html__( 'Show', 'eventful-pro' ),
														'text_off' => esc_html__( 'Hide', 'eventful-pro' ),
														'default' => false,
														'text_width' => 80,
													),
													array(
														'id'   => 'customize_custom_field_name',
														'type' => 'text',
														'title' => esc_html__( 'Customize Field Name', 'eventful-pro' ),
														'dependency' => array( 'show_custom_field_name', '==', 'true' ),
													),
													array(
														'id'   => 'colon_after_custom_field_name',
														'type' => 'switcher',
														'title' => esc_html__( 'Show Colon \':\'', 'eventful-pro' ),
														'title_help' => esc_html__( 'Show colon after field name.', 'eventful-pro' ),
														'text_on' => esc_html__( 'Show', 'eventful-pro' ),
														'text_off' => esc_html__( 'Hide', 'eventful-pro' ),
														'default' => true,
														'text_width' => 80,
														'default' => false,
														'dependency' => array( 'show_custom_field_name', '==', 'true' ),
													),
												),
											), // Group field end.
											array(
												'id'      => 'which_plugin_used',
												'type'    => 'button_set',
												'title'   => esc_html__( 'Select Plugin', 'eventful-pro' ),
												'title_help' => esc_html__( 'Select plugin which is used to make the above custom fields.', 'eventful-pro' ),
												'options' => array(
													'auto' => esc_html__( 'Auto Detect', 'eventful-pro' ),
													'_acf' => esc_html__( 'Advanced Custom Fields', 'eventful-pro' ),
													'_pods' => esc_html__( 'Pods', 'eventful-pro' ),
													'_toolset' => esc_html__( 'Toolset', 'eventful-pro' ),
												),
												'default' => 'auto',
											),
											array(
												'id'    => 'efp_embed_cf_content',
												'type'  => 'checkbox',
												'title' => esc_html__( 'Embed Audio, Video or Image etc.', 'eventful-pro' ),
												'label' =>  __('Embed the content if it is audio, video, or tweets etc. <a target="_blank" href="https://wordpress.org/support/article/embeds/#okay-so-what-sites-can-i-embed-from">See embed supported content list.</a>', 'eventful-pro'),
											),
											array(
												'id'       => 'efp_custom_fields_margin',
												'type'     => 'spacing',
												'title'    => esc_html__( 'Margin', 'eventful-pro' ),
												'sanitize' => 'efp_sanitize_number_array_field',
												'min'      => -100,
												'units'    => array( 'px' ),
												'default'  => array(
													'top'  => '0',
													'right' => '0',
													'bottom' => '15',
													'left' => '0',
												),
											),
										), // End Fields array.
									),
								), // Accordion.
							), // Custom fields end.
						),
					),
					array(
						'id'         => 'show_post_pagination',
						'type'       => 'switcher',
						'text_on'    => esc_html__( 'Enabled', 'eventful-pro' ),
						'text_off'   => esc_html__( 'Disabled', 'eventful-pro' ),
						'text_width' => 100,
						'title'      => esc_html__( 'Pagination', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Enabled/Disabled item pagination.', 'eventful-pro' ),
						'default'    => true,
						'dependency' => array( 'efp_layout_preset', '!=', 'carousel_layout', true ),
					),
					array(
						'id'         => 'post_pagination_type',
						'type'       => 'radio',
						'title'      => esc_html__( 'Pagination Type', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Choose a pagination type.', 'eventful-pro' ),
						'options'    => array(
							'ajax_load_more'  => esc_html__( 'Load More Button (Ajax)', 'eventful-pro' ),
							'ajax_pagination' => esc_html__( 'Ajax Number Pagination', 'eventful-pro' ),
							'infinite_scroll' => esc_html__( 'Infinite Scroll (Ajax)', 'eventful-pro' ),
							'no_ajax'         => esc_html__( 'No Ajax (Normal Pagination)', 'eventful-pro' ),
						),
						'default'    => 'ajax_load_more',
						'dependency' => array( 'efp_layout_preset|show_post_pagination', 'not-any|==', 'carousel_layout,filter_layout|true', true ),
					),
					array(
						'id'         => 'filter_pagination_type',
						'type'       => 'radio',
						'title'      => esc_html__( 'Filter Pagination Type', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Choose a pagination type.', 'eventful-pro' ),
						'options'    => array(
							'ajax_load_more'  => esc_html__( 'Load More Button (Ajax)', 'eventful-pro' ),
							'infinite_scroll' => esc_html__( 'Infinite Scroll (Ajax)', 'eventful-pro' ),
						),
						'default'    => 'ajax_load_more',
						'dependency' => array( 'efp_layout_preset|show_post_pagination', '==|==', 'filter_layout|true', true ),
					),
					array(
						'id'         => 'post_pagination_type_mobile',
						'type'       => 'select',
						'title'      => esc_html__( 'Pagination Type for Mobile', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Choose a pagination type for mobile view.', 'eventful-pro' ),
						'options'    => array(
							'ajax_load_more'  => esc_html__( 'Load More Button (Ajax)', 'eventful-pro' ),
							'ajax_pagination' => esc_html__( 'Ajax Pagination', 'eventful-pro' ),
							'infinite_scroll' => esc_html__( 'Infinite Scroll (Ajax)', 'eventful-pro' ),
							'no_ajax'         => esc_html__( 'No Ajax (Normal Pagination)', 'eventful-pro' ),
						),
						'default'    => 'infinite_scroll',
						'dependency' => array( 'efp_layout_preset|show_post_pagination', 'not-any|==', 'carousel_layout,filter_layout|true', true ),
					),
					array(
						'id'         => 'load_more_button_text',
						'type'       => 'text',
						'title'      => esc_html__( 'Load More Button Label', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Set the label for load more button.', 'eventful-pro' ),
						'default'    => esc_html__('Load More', 'eventful-pro'),
						'dependency' => array( 'efp_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'load_more_ending_message',
						'type'       => 'text',
						'title'      => esc_html__( 'Ending Message', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Set ending message for load more/infinite scroll.', 'eventful-pro' ),
						'default'    => esc_html__( 'No more events available', 'eventful-pro' ),
						'dependency' => array( 'efp_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'efp_pagination_btn_color',
						'type'       => 'color_group',
						'title'      => esc_html__( 'Pagination  Color', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Set Pagination color', 'eventful-pro' ),
						'options'    => array(
							'text_color'        => esc_html__( 'Text Color', 'eventful-pro' ),
							'text_acolor'       => esc_html__( 'Text Active Color', 'eventful-pro' ),
							'border_color'      => esc_html__( 'Border Color', 'eventful-pro' ),
							'border_acolor'     => esc_html__( 'Border Active Color', 'eventful-pro' ),
							'background'        => esc_html__( 'Background', 'eventful-pro' ),
							'active_background' => esc_html__( 'Active BG', 'eventful-pro' ),
						),
						'default'    => array(
							'text_color'        => '#5e5e5e',
							'text_acolor'       => '#ffffff',
							'border_color'      => '#bbbbbb',
							'border_acolor'     => '#0015b5',
							'background'        => '#ffffff',
							'active_background' => '#0015b5',
						),
						'dependency' => array( 'efp_layout_preset|show_post_pagination|post_pagination_type', '!=|==|any', 'carousel_layout|true|ajax_pagination,no_ajax', true ),
					),
					array(
						'id'         => 'efp_loadmore_btn_color',
						'type'       => 'color_group',
						'title'      => esc_html__( 'Load More Button Color', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Set load more button color.', 'eventful-pro' ),
						'options'    => array(
							'text_color'        => esc_html__( 'Text Color', 'eventful-pro' ),
							'text_hcolor'       => esc_html__( 'Text hover Color', 'eventful-pro' ),
							'background'        => esc_html__( 'Background', 'eventful-pro' ),
							'active_background' => esc_html__( 'Hover Background', 'eventful-pro' ),
						),
						'default'    => array(
							'text_color'        => '#ffffff',
							'text_hcolor'       => '#5e5e5e',
							'background'        => '#0015b5',
							'active_background' => '#ffffff',
						),
						'dependency' => array( 'efp_layout_preset|show_post_pagination|post_pagination_type', '!=|==|==', 'carousel_layout|true|ajax_load_more', true ),
					),
					array(
						'id'         => 'pagination_alignment',
						'type'       => 'button_set',
						'title'      => esc_html__( 'Alignment', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Choose pagination alignment.', 'eventful-pro' ),
						'options'    => array(
							'left'   => wp_kses( __('<i class="fas fa-align-left" title="Left"></i>', 'eventful-pro'), array('i' => array('class' => array()))),
							'center' => wp_kses( __('<i class="fas fa-align-center" title="Center"></i>', 'eventful-pro'), array('i' => array('class' => array()))),
							'right'  => wp_kses( __('<i class="fas fa-align-right" title="Right"></i>', 'eventful-pro'), array('i' => array('class' => array()))),
						),
						'default'    => 'left',
						'dependency' => array( 'efp_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'post_per_page',
						'type'       => 'spinner',
						'title'      => esc_html__( 'Items Per Page', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Set number of items to show per page.', 'eventful-pro' ),
						'title_help' => esc_html__( 'This value should be lesser than that <strong> Limit </strong> from <strong>Filter Content  </strong> tab.', 'eventful-pro' ),
						'sanitize'   => 'efp_sanitize_number_field',
						'default'    => 12,
						'dependency' => array( 'efp_layout_preset|show_post_pagination', '!=|==', 'carousel_layout|true', true ),
					),
					array(
						'id'         => 'show_preloader',
						'type'       => 'switcher',
						'title'      => esc_html__( 'Preloader', 'eventful-pro' ),
						'subtitle'   => esc_html__( 'Items will be hidden until page load completed.', 'eventful-pro' ),
						'text_on'    => esc_html__( 'Enabled', 'eventful-pro' ),
						'text_off'   => esc_html__( 'Disabled', 'eventful-pro' ),
						'text_width' => 100,
						'default'    => false,
					),
					array(
						'type'    => 'subheading',
						'class'   => 'efp_filter_btn_color hidden',
						'content' => esc_html__( 'Live Filter Button', 'eventful-pro' ),
					),
				), // End of fields array.
			)
		); // Display settings section end.
	}
}
